<?php

namespace Athira\Forms\Policies;

use Litepie\User\Contracts\UserPolicy;
use Athira\Forms\Models\Athira;

class AthiraPolicy
{

    /**
     * Determine if the given user can view the athira.
     *
     * @param UserPolicy $user
     * @param Athira $athira
     *
     * @return bool
     */
    public function view(UserPolicy $user, Athira $athira)
    {
        if ($user->canDo('forms.athira.view') && $user->isAdmin()) {
            return true;
        }

        return $athira->user_id == user_id() && $athira->user_type == user_type();
    }

    /**
     * Determine if the given user can create a athira.
     *
     * @param UserPolicy $user
     * @param Athira $athira
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('forms.athira.create');
    }

    /**
     * Determine if the given user can update the given athira.
     *
     * @param UserPolicy $user
     * @param Athira $athira
     *
     * @return bool
     */
    public function update(UserPolicy $user, Athira $athira)
    {
        if ($user->canDo('forms.athira.update') && $user->isAdmin()) {
            return true;
        }

        return $athira->user_id == user_id() && $athira->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given athira.
     *
     * @param UserPolicy $user
     * @param Athira $athira
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Athira $athira)
    {
        return $athira->user_id == user_id() && $athira->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given athira.
     *
     * @param UserPolicy $user
     * @param Athira $athira
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Athira $athira)
    {
        if ($user->canDo('forms.athira.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given athira.
     *
     * @param UserPolicy $user
     * @param Athira $athira
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Athira $athira)
    {
        if ($user->canDo('forms.athira.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
